==> lima-swing-0.7-sources.jar: org/chorem/lima/ui/financialtransaction/CreditColumn.java <==
package org.chorem.lima.ui.financialtransaction;

/*
 * #%L
 * Lima :: Swing
 * $Id: CreditColumn.java 3695 2013-07-10 09:11:39Z athimel $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.7/lima-swing/src/main/java/org/chorem/lima/ui/financialtransaction/CreditColumn.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.chorem.lima.entity.Entry;
import org.chorem.lima.ui.celleditor.BigDecimalTableCellEditor;
import org.chorem.lima.ui.celleditor.BigDecimalTableCellRenderer;

import java.math.BigDecimal;

import static org.nuiton.i18n.I18n._;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public class CreditColumn extends FinancialTransactionColumn {

    public CreditColumn(FinancialTransactionTableModel tableModel) {
        super(tableModel);
        renderer = new BigDecimalTableCellRenderer();
        editor = new BigDecimalTableCellEditor();
    }

    @Override
    public Class<?> getColumnClass() {
        return BigDecimal.class;
    }

    @Override
    public String getColumnName() {
        return _("lima.ui.financialtransaction.credit");
    }

    @Override
    public Object getValueAt(int row) {
        Entry entry = tableModel.getEntryAt(row);
        return entry.getDebit() ? BigDecimal.ZERO : entry.getAmount();
    }

    @Override
    public boolean isCellEditable(int row) {
        return true;
    }

    @Override
    public boolean setValueAt(Object value, int row) {
        Entry entry = tableModel.getEntryAt(row);
        BigDecimal credit= (BigDecimal) value;
        boolean update = (credit.signum() > 0 && (entry.isDebit() || entry.getAmount().compareTo(credit) != 0));
        if (update) {
            entry.setAmount(credit);
            entry.setDebit(false);
            tableModel.updateEntry(entry);
            tableModel.fireTransaction(entry.getFinancialTransaction());
        }
        return update;
    }
}

==> lima-swing-0.7.1-sources.jar: org/chorem/lima/ui/financialtransaction/CreditColumn.java <==
package org.chorem.lima.ui.financialtransaction;

/*
 * #%L
 * Lima :: Swing
 * $Id: CreditColumn.java 3727 2014-01-02 09:41:08Z sbavencoff $
 * $HeadURL: https://svn.chorem.org/lima/tags/lima-0.7.1/lima-swing/src/main/java/org/chorem/lima/ui/financialtransaction/CreditColumn.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.chorem.lima.entity.Entry;
import org.chorem.lima.ui.common.AbstractColumn;
import org.chorem.lima.ui.common.FinancialTransactionTableModel;

import java.math.BigDecimal;

import static org.nuiton.i18n.I18n._;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public class CreditColumn extends AbstractColumn<FinancialTransactionTableModel> {

    public CreditColumn() {
        super(BigDecimal.class, _("lima.ui.financialtransaction.credit"), true);
    }

    @Override
    public Object getValueAt(int row) {
        Entry entry = tableModel.get(row);
        return entry.getDebit() ? BigDecimal.ZERO : entry.getAmount();
    }

    @Override
    public boolean setValueAt(Object value, int row) {
        Entry entry = tableModel.get(row);
        BigDecimal credit= (BigDecimal) value;
        boolean update = (credit.signum() > 0 && (entry.isDebit() || entry.getAmount().compareTo(credit) != 0));
        if (update) {
            entry.setAmount(credit);
            entry.setDebit(false);
            tableModel.updateEntry(entry);
            tableModel.fireTransaction(entry.getFinancialTransaction());
        }
        return update;
    }
}
